@@ -1,8 +1,8 @@
-local unpack = require 'luassert.compatibility'.unpack
+local unpack = require 'luassert.util'.unpack
 
 describe("Output testing using string comparison with the equal assertion", function()
   local getoutput = function(...)
-    local success, message = pcall(assert.are.equal, ...)
+    local _, message = pcall(assert.are.equal, ...)
     if message == nil then return nil end
     return tostring(message)
   end
@@ -29,7 +29,7 @@ end)
 
 describe("Output testing using string comparison with the has_error assertion", function()
   local getoutput = function(...)
-    local success, message = pcall(assert.has_error, ...)
+    local _, message = pcall(assert.has_error, ...)
     if message == nil then return nil end
     return tostring(message)
   end
@@ -105,13 +105,24 @@ end)
 
 describe("Output testing using string comparison with the same assertion", function()
   local getoutput = function(...)
-    local success, message = pcall(assert.are.same, ...)
+    local _, message = pcall(assert.are.same, ...)
     if message == nil then return nil end
     return tostring(message)
   end
 
   it("Should compare tables correctly", function()
     -- assert.are.same({1}, {2})
+
+    local old_color = assert:get_parameter("TableErrorHighlightColor")
+    local old_char = assert:get_parameter("TableErrorHighlightCharacter")
+    finally(function()
+      assert:set_parameter("TableErrorHighlightColor", old_color)
+      assert:set_parameter("TableErrorHighlightCharacter", old_char)
+    end)
+
+    assert:set_parameter("TableErrorHighlightColor", "none")
+    assert:set_parameter("TableErrorHighlightCharacter", "*")
+
     local t1, t2 = {1}, {2}
     local output = getoutput(t1, t2)
     local ok = output:find("Passed in:\n("..tostring(t2)..") {\n *[1] = 2 }", nil, true)
@@ -122,6 +133,17 @@ describe("Output testing using string comparison with the same assertion", funct
 
   it("Should compare tables correctly and highlight differences", function()
     -- assert.are.same(t1, t2)
+
+    local old_color = assert:get_parameter("TableErrorHighlightColor")
+    local old_char = assert:get_parameter("TableErrorHighlightCharacter")
+    finally(function()
+      assert:set_parameter("TableErrorHighlightColor", old_color)
+      assert:set_parameter("TableErrorHighlightCharacter", old_char)
+    end)
+
+    assert:set_parameter("TableErrorHighlightColor", "none")
+    assert:set_parameter("TableErrorHighlightCharacter", "**")
+
     local t1 = {1, {"a", "b", {"foo", "bar"} }, "c"}
     local t2 = {1, {"a", "b", {"bar", "bar"} }, "c"}
     local output = getoutput(t1, t2)
@@ -138,14 +160,14 @@ describe("Output testing using custom failure message", function()
     local argcnt = select("#", ...)
     local args = {...}
     args[argcnt+1] = key .. " fails"
-    local success, message = pcall(assert[key], unpack(args, 1, argcnt+1))
+    local _, message = pcall(assert[key], unpack(args, 1, argcnt+1))
     if message == nil then return nil end
     message = tostring(message):gsub("\n.*", ""):gsub("^.-:%d+: ", "", 1)
     return message
   end
 
   local geterror2 = function(key, ...)
-    local success, message = pcall(assert.message(key .. " fails")[key], ...)
+    local _, message = pcall(assert.message(key .. " fails")[key], ...)
     if message == nil then return nil end
     message = tostring(message):gsub("\n.*", ""):gsub("^.-:%d+: ", "", 1)
     return message
@@ -329,7 +351,7 @@ for _,ss in ipairs({"spy", "stub"}) do
 
     local geterror = function(key, args, ...)
       local err = select('#', ...) == 0 and key .. " failed" or ...
-      local success, message = pcall(assert[ss](test.key, err)[key], unpack(args))
+      local _, message = pcall(assert[ss](test.key, err)[key], unpack(args))
       if message == nil then return nil end
       message = tostring(message):gsub("\n.*", ""):gsub("^.-:%d+: ", "", 1)
       return message
@@ -337,7 +359,7 @@ for _,ss in ipairs({"spy", "stub"}) do
 
     local geterror2 = function(key, args, ...)
       local err = select('#', ...) == 0 and key .. " failed" or ...
-      local success, message = pcall(assert.message(err).spy(test.key)[key], unpack(args))
+      local _, message = pcall(assert.message(err).spy(test.key)[key], unpack(args))
       if message == nil then return nil end
       message = tostring(message):gsub("\n.*", ""):gsub("^.-:%d+: ", "", 1)
       return message
